@@ -1,9 +1,10 @@
 """This is a simple function that does recursion"""
-def print_lol(the_list, level = 0):
+def print_lol(the_list, indent = False, level = 0):
     for each_item in the_list:
         if isinstance(each_item, list):
             print_lol(each_item, level + 1)
         else:
-            for num in range(level):
-                each_item = " "+each_item
+            if indent:
+                for num in range(level):
+                    each_item = " "+each_item
             print(each_item)
